/* eslint-disable security/detect-object-injection */
'use strict';

const mimeDb = require('mime-db');

const defaultType = 'application/octet-stream';
const extension = {};
for (const [mimeType, entry] of Object.entries(mimeDb)) {
  if (entry.extensions) {
    entry.extensions.forEach((ext) => {
      if (!(ext in extension)) {
        extension[ext] = [];
      }
      extension[ext].push(mimeType);
    });
  }
}

/**
 * Return a suitable type for a file extension.
 * @param {string} ext file extension
 * @param {string} def type to return if no match
 */
const extensionToMime = (ext, def = defaultType) => extension[ext] && extension[ext][extension[ext].length - 1] || def;

module.exports = {
  extensionToMime,
};
