'use strict';

const parameters = new Map();
/**
 * De-duplicating factory of minimal-objects to track the named-parameter parts of path definitions.
 *
 * @property {String} parameter
 */
class PathParameter extends null {
  constructor(parameter) {
    if (!parameter || typeof(parameter) !== 'string') {
      throw new RangeError('parameter must be string');
    }
    if (parameters.has(parameter)) {
      return parameters.get(parameter);
    }
    const pathParameter = Object.create(PathParameter.prototype);
    pathParameter.parameter = parameter;
    parameters.set(parameter, pathParameter);
    Object.freeze(pathParameter);
    return pathParameter;
  }

  /**
   * @returns {String}
   */
  toString() {
    return `{${this.constructor.name} ${this.parameter}}`;
  }

  /**
   * Clear the de-duplication table, for tests.
   */
  static _flush() {
    this.parameters.clear();
  }
}
PathParameter.parameters = parameters;

module.exports = PathParameter;